translate.convert.moz2po

Package translate :: Package convert :: Module moz2po |
[hide private]
[frames] | no frames]

# Module moz2po

source code

convert Mozilla .dtd and .properties files to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/moz2po for examples and usage instructions

Functions | [hide private]
main(argv=None) | source code

Imports: dtd2po, prop2po, mozfunny2prop, xpi, convert